==> v0.6.0.zip: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/action/support/broadcast/BroadcastOperationResponse.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.action.support.broadcast;

import com.google.common.collect.ImmutableList;
import org.elasticsearch.action.ActionResponse;
import org.elasticsearch.action.ShardOperationFailedException;
import org.elasticsearch.util.io.stream.StreamInput;
import org.elasticsearch.util.io.stream.StreamOutput;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import static org.elasticsearch.action.support.DefaultShardOperationFailedException.*;

/**
 * Base class for all broadcast operation based responses.
 *
 * @author kimchy (shay.banon)
 */
public abstract class BroadcastOperationResponse implements ActionResponse {

    private int totalShards;

    private int successfulShards;

    private int failedShards;

    private List<ShardOperationFailedException> shardFailures = ImmutableList.of();

    protected BroadcastOperationResponse() {
    }

    protected BroadcastOperationResponse(int totalShards, int successfulShards, int failedShards, List<ShardOperationFailedException> shardFailures) {
        this.totalShards = totalShards;
        this.successfulShards = successfulShards;
        this.failedShards = failedShards;
        this.shardFailures = shardFailures;
        if (shardFailures == null) {
            this.shardFailures = ImmutableList.of();
        }
    }

    /**
     * The total shards this request ran against.
     */
    public int totalShards() {
        return totalShards;
    }

    /**
     * The successful shards this request was executed on.
     */
    public int successfulShards() {
        return successfulShards;
    }

    /**
     * The failed shards this request was executed on.
     */
    public int failedShards() {
        return failedShards;
    }

    /**
     * The list of shard failures exception.
     */
    public List<? extends ShardOperationFailedException> shardFailures() {
        if (shardFailures == null) {
            return ImmutableList.of();
        }
        return shardFailures;
    }

    @Override public void readFrom(StreamInput in) throws IOException {
        totalShards = in.readVInt();
        successfulShards = in.readVInt();
        failedShards = in.readVInt();
        int size = in.readVInt();
        if (size > 0) {
            shardFailures = new ArrayList<ShardOperationFailedException>(size);
            for (int i = 0; i < size; i++) {
                shardFailures.add(readShardOperationFailed(in));
            }
        }
    }

    @Override public void writeTo(StreamOutput out) throws IOException {
        out.writeVInt(totalShards);
        out.writeVInt(successfulShards);
        out.writeVInt(failedShards);
        out.writeVInt(shardFailures.size());
        for (ShardOperationFailedException exp : shardFailures) {
            exp.writeTo(out);
        }
    }
}

==> v0.7.0.zip: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/action/support/broadcast/BroadcastOperationResponse.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.action.support.broadcast;

import org.elasticsearch.action.ActionResponse;
import org.elasticsearch.action.ShardOperationFailedException;
import org.elasticsearch.util.collect.ImmutableList;
import org.elasticsearch.util.io.stream.StreamInput;
import org.elasticsearch.util.io.stream.StreamOutput;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import static org.elasticsearch.action.support.DefaultShardOperationFailedException.*;

/**
 * Base class for all broadcast operation based responses.
 *
 * @author kimchy (shay.banon)
 */
public abstract class BroadcastOperationResponse implements ActionResponse {

    private int totalShards;

    private int successfulShards;

    private int failedShards;

    private List<ShardOperationFailedException> shardFailures = ImmutableList.of();

    protected BroadcastOperationResponse() {
    }

    protected BroadcastOperationResponse(int totalShards, int successfulShards, int failedShards, List<ShardOperationFailedException> shardFailures) {
        this.totalShards = totalShards;
        this.successfulShards = successfulShards;
        this.failedShards = failedShards;
        this.shardFailures = shardFailures;
        if (shardFailures == null) {
            this.shardFailures = ImmutableList.of();
        }
    }

    /**
     * The total shards this request ran against.
     */
    public int totalShards() {
        return totalShards;
    }

    /**
     * The total shards this request ran against.
     */
    public int getTotalShards() {
        return totalShards;
    }

    /**
     * The successful shards this request was executed on.
     */
    public int successfulShards() {
        return successfulShards;
    }

    /**
     * The successful shards this request was executed on.
     */
    public int getSuccessfulShards() {
        return successfulShards;
    }

    /**
     * The failed shards this request was executed on.
     */
    public int failedShards() {
        return failedShards;
    }

    /**
     * The failed shards this request was executed on.
     */
    public int getFailedShards() {
        return failedShards;
    }

    /**
     * The list of shard failures exception.
     */
    public List<? extends ShardOperationFailedException> shardFailures() {
        if (shardFailures == null) {
            return ImmutableList.of();
        }
        return shardFailures;
    }

    /**
     * The list of shard failures exception.
     */
    public List<ShardOperationFailedException> getShardFailures() {
        return shardFailures;
    }

    @Override public void readFrom(StreamInput in) throws IOException {
        totalShards = in.readVInt();
        successfulShards = in.readVInt();
        failedShards = in.readVInt();
        int size = in.readVInt();
        if (size > 0) {
            shardFailures = new ArrayList<ShardOperationFailedException>(size);
            for (int i = 0; i < size; i++) {
                shardFailures.add(readShardOperationFailed(in));
            }
        }
    }

    @Override public void writeTo(StreamOutput out) throws IOException {
        out.writeVInt(totalShards);
        out.writeVInt(successfulShards);
        out.writeVInt(failedShards);
        out.writeVInt(shardFailures.size());
        for (ShardOperationFailedException exp : shardFailures) {
            exp.writeTo(out);
        }
    }
}
